==> CGAL-5.2.2-doc_html.tar.xz: doc_html/BGL/navtreedata.js <==
var NAVTREE =
[
  [ "CGAL 5.2.2 - CGAL and the Boost Graph Library", "index.html", [
    [ "User Manual", "index.html", [
      [ "A Short Introduction to the Boost Graph Library", "index.html#BGLA", [
        [ "Graph Concepts", "index.html#BGLGraphConcepts", null ],
        [ "The Graph Traits Class", "index.html#BGLTheGraphTraitsClass", null ],
        [ "Free Functions for Exploring a Graph", "index.html#BGLFreeFunctionsforExploringaGraph", null ],
        [ "Property Maps", "index.html#BGLPropertyMaps", null ],
        [ "Visitors", "index.html#BGLVisitors", null ],
        [ "Named Parameters", "index.html#BGLNamedParameters", [
          [ "Example", "index.html#BGLNamedParametersExample", null ]
        ] ]
      ] ],
      [ "Header Files, Namespaces, and Naming Conventions", "index.html#BGLHeader", null ],
      [ "The Class Surface_mesh as Model of the Boost Graph Concept", "index.html#BGLSurface_mesh", [
        [ "Example: Minimum Spanning Tree of a Surface_mesh", "index.html#BGLExampleMinimumSpanningTreeofaSurfaceMesh", null ]
      ] ],
      [ "The Class Polyhedron_3 as Model of the Boost Graph Concept", "index.html#BGLPolyhedral", [
        [ "Example: Minimum Spanning Tree of a Polyhedral Surface", "index.html#BGLExampleMinimumSpanningTreeofaPolyhedral", null ],
        [ "Example: Using Vertices, and Edges with an ID", "index.html#BGLExampleUsingVerticesandEdgeswithanID", null ]
      ] ],
      [ "Triangulations as Models of the Boost Graph Concept", "index.html#BGLTriangulations", [
        [ "Example: Euclidean Minimum Spanning Tree", "index.html#BGLExampleEuclideanMinimumSpanningTree", null ],
        [ "Example: Storing the Vertex ID in the Vertex", "index.html#BGLExampleStoringtheVertexIDintheVertex", null ]
      ] ],
      [ "Arrangements as Models of the Boost Graph Concept", "index.html#BGLArrangements", [
        [ "Example for the Arrangement as Graph", "index.html#arr_sssecbgl_primal", null ],
        [ "Example for the Dual of an Arrangement as Graph", "index.html#arr_sssecbgl_dual", null ]
      ] ],
      [ "Extensions of the BGL", "index.html#BGLExtensions", [
        [ "Graph concepts", "index.html#BGLExtensionsGraphConcepts", null ],
        [ "Iterators and Circulators", "index.html#BGLIteratorsAndCirculators", [
          [ "Example: Finding Incident Vertices in a HalfedgeGraph", "index.html#BGLExampleIncidentVertices", null ],
          [ "Example: Calculating Facet Normals using HalfedgeGraph", "index.html#BGLExampleNormalHalfedgeGraph", null ]
        ] ],
        [ "Properties and Dynamic Properties", "index.html#BGLProperties", null ]
      ] ],
      [ "Euler Operations", "index.html#BGLEulerOperations", null ],
      [ "Graph Adaptors", "index.html#BGLGraphAdaptors", [
        [ "The Dual Graph", "index.html#BGLDual", null ],
        [ "The Seam Mesh", "index.html#BGLSeamMesh", [
          [ "Seam Mesh Traversal", "index.html#BGLSeamMeshTraversal", null ],
          [ "Seams", "index.html#BGLSeamMeshNature", null ]
        ] ],
        [ "Inheriting from a Model of a Face Graph Concept", "index.html#BGLInheriting", null ]
      ] ],
      [ "Graph Partitioning", "index.html#BGLPartitioning", null ],
      [ "Graph Cut", "index.html#BGLGraphcut", [
        [ "Example", "index.html#BGLGraphcutExample", null ],
        [ "Application to Regularization of the Borders of a Face Selection", "index.html#BGLGraphcutRegularizeSelection", null ]
      ] ]
    ] ],
    [ "Reference Manual", "modules.html", "modules" ],
    [ "Refinement Relationships", "refines.html", null ],
    [ "Is Model Relationships", "models.html", null ],
    [ "Has Model Relationships", "hasModels.html", null ],
    [ "Bibliography", "citelist.html", null ],
    [ "Class and Concept List", "annotated.html", "annotated" ],
    [ "Examples", "examples.html", "examples" ]
  ] ]
];

var NAVTREEINDEX =
[
"BGL_arrangement_2_2arr_print_8h-example.html",
"group__PkgBGLSelectionFct.html#ga0fed4caaddf3fef51b37a64b42ba5fc0"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';

==> CGAL-5.4.1-doc_html.tar.xz: doc_html/BGL/navtreedata.js <==
var NAVTREE =
[
  [ "CGAL 5.4.1 - CGAL and the Boost Graph Library", "index.html", [
    [ "User Manual", "index.html", [
      [ "A Short Introduction to the Boost Graph Library", "index.html#BGLA", [
        [ "Graph Concepts", "index.html#BGLGraphConcepts", null ],
        [ "The Graph Traits Class", "index.html#BGLTheGraphTraitsClass", null ],
        [ "Free Functions for Exploring a Graph", "index.html#BGLFreeFunctionsforExploringaGraph", null ],
        [ "Property Maps", "index.html#BGLPropertyMaps", null ],
        [ "Visitors", "index.html#BGLVisitors", null ],
        [ "Named Parameters", "index.html#BGLNamedParameters", [
          [ "Example", "index.html#BGLNamedParametersExample", null ]
        ] ]
      ] ],
      [ "Header Files, Namespaces, and Naming Conventions", "index.html#BGLHeader", null ],
      [ "The Class Surface_mesh as Model of the Boost Graph Concept", "index.html#BGLSurface_mesh", [
        [ "Example: Minimum Spanning Tree of a Surface_mesh", "index.html#BGLExampleMinimumSpanningTreeofaSurfaceMesh", null ]
      ] ],
      [ "The Class Polyhedron_3 as Model of the Boost Graph Concept", "index.html#BGLPolyhedral", [
        [ "Example: Minimum Spanning Tree of a Polyhedral Surface", "index.html#BGLExampleMinimumSpanningTreeofaPolyhedral", null ],
        [ "Example: Using Vertices, and Edges with an ID", "index.html#BGLExampleUsingVerticesandEdgeswithanID", null ]
      ] ],
      [ "Triangulations as Models of the Boost Graph Concept", "index.html#BGLTriangulations", [
        [ "Example: Euclidean Minimum Spanning Tree", "index.html#BGLExampleEuclideanMinimumSpanningTree", null ],
        [ "Example: Storing the Vertex ID in the Vertex", "index.html#BGLExampleStoringtheVertexIDintheVertex", null ]
      ] ],
      [ "Arrangements as Models of the Boost Graph Concept", "index.html#BGLArrangements", [
        [ "Example for the Arrangement as Graph", "index.html#arr_sssecbgl_primal", null ],
        [ "Example for the Dual of an Arrangement as Graph", "index.html#arr_sssecbgl_dual", null ]
      ] ],
      [ "Extensions of the BGL", "index.html#BGLExtensions", [
        [ "Graph concepts", "index.html#BGLExtensionsGraphConcepts", null ],
        [ "Iterators and Circulators", "index.html#BGLIteratorsAndCirculators", [
          [ "Example: Finding Incident Vertices in a HalfedgeGraph", "index.html#BGLExampleIncidentVertices", null ],
          [ "Example: Calculating Facet Normals using HalfedgeGraph", "index.html#BGLExampleNormalHalfedgeGraph", null ]
        ] ],
        [ "Properties and Dynamic Properties", "index.html#BGLProperties", null ],
        [ "Graph I/O", "index.html#BGLGraphIO", null ]
      ] ],
      [ "Euler Operations", "index.html#BGLEulerOperations", null ],
      [ "Graph Adaptors", "index.html#BGLGraphAdaptors", [
        [ "The Dual Graph", "index.html#BGLDual", null ],
        [ "The Seam Mesh", "index.html#BGLSeamMesh", [
          [ "Seam Mesh Traversal", "index.html#BGLSeamMeshTraversal", null ],
          [ "Seams", "index.html#BGLSeamMeshNature", null ]
        ] ],
        [ "Inheriting from a Model of a Face Graph Concept", "index.html#BGLInheriting", null ]
      ] ],
      [ "Graph Partitioning", "index.html#BGLPartitioning", null ],
      [ "Graph Cut", "index.html#BGLGraphcut", [
        [ "Example", "index.html#BGLGraphcutExample", null ],
        [ "Application to Regularization of the Borders of a Face Selection", "index.html#BGLGraphcutRegularizeSelection", null ]
      ] ]
    ] ],
    [ "Reference Manual", "modules.html", "modules" ],
    [ "Refinement Relationships", "refines.html", null ],
    [ "Deprecated List", "deprecated.html", null ],
    [ "Is Model Relationships", "models.html", null ],
    [ "Has Model Relationships", "hasModels.html", null ],
    [ "Bibliography", "citelist.html", null ],
    [ "Class and Concept List", "annotated.html", "annotated" ],
    [ "Examples", "examples.html", "examples" ]
  ] ]
];

var NAVTREEINDEX =
[
"BGL_arrangement_2_2arr_print_8h-example.html",
"group__PkgBGLIoFuncsPLY.html#ga85c1511e4de8e8e9a00502f71a58e867"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';
